(build-router api-def routers)(build-url elems params)(gen-path elems)(generate-router api-def)(generate-router {:keys [commands router] :as api-def} options)Takes an api definition that has been parsed by blueprint.core/parse
Takes an api definition that has been parsed by `blueprint.core/parse`
(prepare-route options routers opname {:keys [path]})(uri-for {:keys [commands]} nick params)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |